# static-sitemap

- [PyPi page](https://pypi.org/project/static-sitemap/)
- [PyPiStats](https://pypistats.org/packages/static-sitemap)
- [GitHub repo](https://github.com/Its-Just-Nans/static-sitemap)

## How to use

```sh
# install
python -m pip install static_sitemap

python -m static_sitemap https://its-just-nans.github.io/
```

## Options

- `--verbose` : Display URLs
- `--quiet` : Display Nothing
- `--sitemap` : Create a `sitemap.xml` file
- `--rm-error` : Delete link with request error
- `--html` : to display the html from requests

## Others files

- `other.html` is useless
